@@ -1,7 +1,7 @@
 """
     test_domonic
     ~~~~~~~~~~~~
-    unit tests for css
+    unit tests for CDN
 """
 
 import unittest
@@ -9,11 +9,6 @@ import unittest
 from domonic.CDN import CDN_CSS, CDN_IMG, CDN_JS
 from domonic.html import img, link, script
 
-# import json
-# import requests
-# from mock import patch
-
-
 
 class TestCase(unittest.TestCase):
 
